==> bytecode-disassembler_2.11-0.8.13-sources.jar: org/opalj/da/CONSTANT_InvokeDynamic_info.scala <==
/* BSD 2-Clause License:
 * Copyright (c) 2009 - 2017
 * Software Technology Group
 * Department of Computer Science
 * Technische Universität Darmstadt
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.opalj
package da

import scala.xml.Node
import scala.xml.Text
import org.opalj.bi.ConstantPoolTag

/**
 *
 * @author Michael Eichberg
 */
case class CONSTANT_InvokeDynamic_info(
        bootstrap_method_attr_index: Int,
        name_and_type_index:         Constant_Pool_Index
) extends Constant_Pool_Entry {

    override final def size: Int = 1 + 2 + 2

    override def Constant_Type_Value: ConstantPoolTag = bi.ConstantPoolTags.CONSTANT_InvokeDynamic

    override def asCPNode(implicit cp: Constant_Pool): Node = {
        <div class="cp_entry">
            { this.getClass().getSimpleName }
            (<div class="attributes_ref">
                 bootstrap_method_attr_index={ bootstrap_method_attr_index }
             </div>
            <div class="cp_ref">
                name_and_type_index={ name_and_type_index }
                &laquo;
                { cp(name_and_type_index).asCPNode }
                &raquo;
            </div>
            )
        </div>
    }

    override def asInlineNode(implicit cp: Constant_Pool): Node = {
        val ntiNode = cp(name_and_type_index).asInlineNode
        val paramsNode =
            Seq(
                ntiNode,
                Text(s" //Bootstrap Method Attribute[$bootstrap_method_attr_index]")
            )
        <span class="cp_entry">{ paramsNode }</span>
    }

    override def toString(implicit cp: Constant_Pool): String = {
        "CONSTANT_InvokeDynamic_info("+
            s"$bootstrap_method_attr_index,"+
            s"${cp(name_and_type_index).toString(cp)}/*$name_and_type_index */ "+
            ")"
    }
}

==> bytecode-disassembler_2.11-0.8.15-sources.jar: org/opalj/da/CONSTANT_InvokeDynamic_info.scala <==
/* BSD 2-Clause License:
 * Copyright (c) 2009 - 2017
 * Software Technology Group
 * Department of Computer Science
 * Technische Universität Darmstadt
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.opalj
package da

import scala.xml.Node
import scala.xml.Text
import org.opalj.bi.ConstantPoolTag

import scala.xml.NodeSeq

/**
 *
 * @author Michael Eichberg
 */
case class CONSTANT_InvokeDynamic_info(
        bootstrap_method_attr_index: Int,
        name_and_type_index:         Constant_Pool_Index
) extends Constant_Pool_Entry {

    override final def size: Int = 1 + 2 + 2

    override def Constant_Type_Value: ConstantPoolTag = bi.ConstantPoolTags.CONSTANT_InvokeDynamic

    override def asCPNode(implicit cp: Constant_Pool): Node = {
        <div class="cp_entry">
            { this.getClass().getSimpleName }
            (<div class="attributes_ref">
                 bootstrap_method_attr_index={ bootstrap_method_attr_index }
             </div>
            <div class="cp_ref">
                name_and_type_index={ name_and_type_index }
                &laquo;
                { cp(name_and_type_index).asCPNode }
                &raquo;
            </div>
            )
        </div>
    }

    override def asInstructionParameter(implicit cp: Constant_Pool): NodeSeq = {
        val ntiNode = cp(name_and_type_index).asInstructionParameter
        val paramsNode =
            Seq(
                ntiNode,
                Text(s" //Bootstrap Method Attribute[$bootstrap_method_attr_index]")
            )
        <span class="cp_entry">{ paramsNode }</span>
    }

    override def toString(implicit cp: Constant_Pool): String = {
        "CONSTANT_InvokeDynamic_info("+
            s"$bootstrap_method_attr_index,"+
            s"${cp(name_and_type_index).toString(cp)}/*$name_and_type_index */ "+
            ")"
    }
}
